#ifndef QT_FEATURES_Sensors_src_sensors_qtsensors_config_p_h_H
#define QT_FEATURES_Sensors_src_sensors_qtsensors_config_p_h_H

#define QT_FEATURE_sensorfw -1

#define QT_FEATURE_winrt_sensors -1


#endif // QT_FEATURES_Sensors_src_sensors_qtsensors_config_p_h_H
